Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(186)

Unified Diff: components/url_formatter/elide_url.h

Issue 1171333003: Move net::FormatUrl and friends outside of //net and into //components (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase again now that CQ is fixed Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/url_formatter/OWNERS ('k') | components/url_formatter/elide_url.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/url_formatter/elide_url.h
diff --git a/components/secure_display/elide_url.h b/components/url_formatter/elide_url.h
similarity index 89%
rename from components/secure_display/elide_url.h
rename to components/url_formatter/elide_url.h
index 7d77b0453a4a0f8d47a52198f08162e1a6949823..528b20e294c252699c6e08fad3ee6367d31b632f 100644
--- a/components/secure_display/elide_url.h
+++ b/components/url_formatter/elide_url.h
@@ -4,8 +4,8 @@
//
// This file defines utility functions for eliding URLs.
-#ifndef COMPONENTS_SECURE_DISPLAY_ELIDE_URL_H_
-#define COMPONENTS_SECURE_DISPLAY_ELIDE_URL_H_
+#ifndef COMPONENTS_URL_FORMATTER_ELIDE_URL_H_
+#define COMPONENTS_URL_FORMATTER_ELIDE_URL_H_
#include <string>
@@ -17,7 +17,7 @@ namespace gfx {
class FontList;
}
-namespace secure_display {
+namespace url_formatter {
// ElideUrl and Elide host require
// gfx::GetStringWidthF which is not implemented in Android
@@ -57,8 +57,8 @@ base::string16 ElideHost(const GURL& host_url,
// otherwise-simplified URLs from each other).
//
// Internationalized domain names (IDN) may be presented in Unicode if
// |languages| accepts the Unicode representation (see |net::FormatUrl| for more
// details on the algorithm).
//
// - Omits the path for standard schemes, excepting file and filesystem.
// - Omits the port if it is the default for the scheme.
@@ -67,6 +67,6 @@ base::string16 ElideHost(const GURL& host_url,
base::string16 FormatUrlForSecurityDisplay(const GURL& origin,
const std::string& languages);
-} // namespace secure_display
+} // namespace url_formatter
-#endif // COMPONENTS_SECURE_DISPLAY_ELIDE_URL_H_
+#endif // COMPONENTS_URL_FORMATTER_ELIDE_URL_H_
« no previous file with comments | « components/url_formatter/OWNERS ('k') | components/url_formatter/elide_url.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -57,8 +57,8 @@ base::string16 ElideHost(const GURL& host_url,
//
// Internationalized domain names (IDN) may be presented in Unicode if
-// |languages| accepts the Unicode representation (see |net::FormatUrl| for more
-// details on the algorithm).
+// |languages| accepts the Unicode representation (see
+// |url_formatter::FormatUrl| for more details on the algorithm).
//
// - Omits the path for standard schemes, excepting file and filesystem.
This is Rietveld 408576698